################
Json Line Logger
################
|TestStatus| |PyPiStatus| |BlackStyle|


Uses python's awesome logging-library and configures it to write JSON-lines.
In JSON-lines, each line in the log is a valid json-object.
This makes the log easy to read with a machine.


.. |TestStatus| image:: https://github.com/cherenkov-plenoscope/json_line_logger/actions/workflows/test.yml/badge.svg?branch=main
    :target: https://github.com/cherenkov-plenoscope/json_line_logger/actions/workflows/test.yml

.. |PyPiStatus| image:: https://img.shields.io/pypi/v/json_line_logger
    :target: https://pypi.org/project/json_line_logger

.. |BlackStyle| image:: https://img.shields.io/badge/code%20style-black-000000.svg
    :target: https://github.com/psf/black
